@@ -533,10 +533,10 @@ removePrintVersion lem
 
 goodtags1 :: [[Char]]
 goodtags1
-  = ["templatestyles", "includeonly", "references", "blockquote", "noinclude",
+  = ["templatestyles", "includeonly", "references", "blockquote", "noinclude", "figcaption",
      "noframes", "frameset", "colgroup", "fieldset", "basefont",
      "!DOCTYPE", "noscript", "address", "acronym", "caption", "strong",
-     "applet", "script", "button", "select", "section", "legend", "footer", "header",
+     "applet", "script", "button", "select", "section", "legend", "footer", "figure","header",
      "strike", "object", "input", "center", "legend", "iframe", "small",
      "video", "audio", "style", "input", "label", "tbody", "thead",
      "title", "track" ,"frame", "param", "base", "area", "font", "code", "span", "main",
